# 安装
pip install GPminer

注意：joblib==1.0.1

# GPstrat 主要模块
遗传算法策略挖掘框架

![image](https://github.com/user-attachments/assets/1eaa5124-3c13-4cdb-ac80-6d6cd683b0f7)


# hello world
demo文件夹，数据与自定义参数可修改



